@@ -17,13 +17,8 @@ apiKey = config('monday_apikey')
 apiUrl = "https://api.monday.com/v2"
 headers = {"Authorization": apiKey, "Content-Type ": "application/json"}
 
-
 @click.group()
-def main():
-    pass
-
-
-@main.command()
+@click.command()
 def cli():
     """Example script."""
     file_exists = exists(os.getcwd() + '/audit-dog.yml')
@@ -38,8 +33,7 @@ def cli():
             data = yaml.dump(yml_data, f, sort_keys=False, default_flow_style=False)
             print(data)
 
-
-@main.command()
+@click.command()
 def run():
     name = GetBoardFromGitlab()
     non_conformance_id = config('non_conformance_id')
